$rDef = {
  'icon' => 'Radiobutton',
  'geom' => '1',
  'file' => 'Radiobutton',
  'attr' => {
    '-fg' => 'color',
    '-foreground' => 'color',
    '-highlightcolor' => 'color',
    '-height' => 'int+',
    '-value' => 'text',
    '-textvariable' => 'variable',
    '-variable' => 'variable',
    '-font' => 'text',
    '-anchor' => 'anchor',
    '-pady' => 'int+',
    '-bg' => 'color',
    '-indicatoron' => 'menu(0|1)',
    '-command' => 'callback',
    '-width' => 'int+',
    '-state' => 'menu(normal|active|disabled)',
    '-selectimage' => 'file',
    '-justify' => 'justify',
    '-text' => 'text',
    '-bitmap' => 'file',
    '-image' => 'file',
    '-padx' => 'int+',
    '-selectcolor' => 'color'
  },
  'classname' => 'Radiobutton',
  'use' => 'Tk::Radiobutton',
  'nonVisual' => '0',
  'defaultgeometrymanager' => 'pack',
  'balloon' => '1',
  'defaultgeometryoptions' => undef,
  'defaultwidgetoptions' => undef
};
